@@ -5,7 +5,8 @@ require(strucchange)
 ##
 ".fecov" <-
 function(x, n.ahead) {
-  sigma.u <- crossprod(resid(x))/(x$obs - ncol(x$datamat[, -c(1:x$K)]))
+  n.par<-sapply(x$varresult, function(x) summary(x)$df[2])
+  sigma.u <- crossprod(resid(x))/n.par
   Sigma.yh <- array(NA, dim = c(x$K, x$K, n.ahead))
   Sigma.yh[, , 1] <- sigma.u
   Phi <- Phi(x, nstep = n.ahead)
